This package provides tools to render and capture kart training data using 'HTML' widgets and 'Shiny' applications.
This package can be used to: Collect kart playing styles, create test cases for image classification and render trained models over an interactive kart simulation.
Maintainer: Javier Luraschi javier@rstudio.com
Authors:
three.js authors (Rendering Engine)
Rick Bruns rick@nintendomaps.com (Circuit Texture)
khinsider.com authors (Circuit Audio)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.